mercurial/localrepo.py
changeset 1788 750b9cd83965
parent 1787 e431344e604c
child 1789 d5248726d22f
--- a/mercurial/localrepo.py	Tue Feb 21 23:21:15 2006 +0100
+++ b/mercurial/localrepo.py	Tue Feb 21 23:50:53 2006 +0100
@@ -262,9 +262,9 @@
                 raise inst
             self.ui.warn(_("waiting for lock held by %s\n") % inst.args[0])
             try:
                 # default to 1024 seconds timeout
                 l = lock.lock(self.join(lockname),
-                              int(self.ui.config("ui", "timeout") or 1024),
+                              int(self.ui.config("ui", "timeout") or 600),
                               releasefn)
             except lock.LockHeld, inst:
                 raise util.Abort(_("timeout while waiting for "
@@ -262,9 +262,9 @@
             self.ui.warn(_("waiting for lock held by %s\n") % inst.args[0])
             try:
-                # default to 1024 seconds timeout
+                # default to 600 seconds timeout
                 l = lock.lock(self.join(lockname),